#
# spec file for package kopia
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           kopia
Version:        0.19.0
Release:        1.2
Summary:        Cross-platform backup tool with fast incremental backups
License:        Apache-2.0
URL:            https://github.com/kopia/kopia
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  go >= 1.22

%description
Kopia is a fast and secure open-source backup/restore tool that allows you to
create encrypted snapshots of your data and save the snapshots to remote or
cloud storage of your choice, to network-attached storage or server, or locally
on your machine. Kopia does not 'image' your whole machine. Rather, Kopia
allows you to backup/restore any and all files/directories that you deem are
important or critical.

%prep
%autosetup -p 1 -a 1

%build
COMMIT_HASH="$(sed -n 's/commit: \(.*\)/\1/p' %_sourcedir/%{name}.obsinfo)"

go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags=" \
   -X github.com/kopia/kopia/repo.BuildVersion=%{version} \
   -X github.com/kopia/kopia/repo.BuildInfo=${COMMIT_HASH} \
   -X github.com/kopia/kopia/repo.BuildGitHubRepo=kopia/kopia" \
   -o bin/%{name} github.com/kopia/kopia

%install
# Install the binary.
install -D -m 0755 bin/%{name} %{buildroot}/%{_bindir}/%{name}

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}

%changelog
* Fri Jan 24 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.19.0:
  * build(deps): bump codecov/codecov-action to 5.2.0 (#4362)
  * build(deps): bump docker/setup-qemu-action (#4361)
  * build(deps):
    github.com/Azure/azure-sdk-for-go/sdk/storage/azblob (#4360)
  * fix(server): ensure server uploads "repodiag" blobs (#4358)
  * chore(general): reduce verbosity for noisy log message (#4357)
  * build(deps): bump google.golang.org/api (#4356)
  * build(deps): drop Go patch version to 1.22.0 (#4353)
  * build(deps): upgrade grpc and opentelemetry dependencies
    (#4354)
  * feat(kopiaui): support for desktop notifications (#4352)
  * build(deps): bump the telemetry-dependencies group with 4
    updates (#4350)
  * build(deps): bump the common-golang-dependencies group with 3
    updates (#4349)
  * test(general): cleanup symlink tests (#4347)
  * build(deps): bump github.com/sanity-io/litter from 1.5.5 to
    1.5.6 (#4344)
  * build(deps): bump github.com/mattn/go-colorable from 0.1.13 to
    0.1.14 (#4343)
  * build(deps): bump cloud.google.com/go/storage (#4342)
  * build(deps): bump github.com/minio/minio-go/v7 from 7.0.82 to
    7.0.83 in the common-golang-dependencies group (#4337)
  * feat(notifications): tweak snapshot report template (#4338)
  * Update command_benchmark_compression.go (#4339)
  * build(deps): bump the kopia-ui-npm-dependencies group (#4327)
  * build(deps): bump codecov/codecov-action from 5.0.7 to 5.1.2
    (#4330)
  * build(deps): bump docker/setup-buildx-action in the docker
    group (#4329)
  * build(deps): bump the github-actions group with 3 updates
    (#4328)
  * build(deps): bump github.com/studio-b12/gowebdav from 0.9.0 to
    0.10.0 (#4315)
  * build(deps): bump the common-golang-dependencies group across 1
    directory with 8 updates (#4336)
  * feat(server): emit notifications as JSON to stderr when running
    under KopiaUI (#4322)
  * feat(notifications): emit snapshot report notifications in the
    UI/server (#4323)
  * feat(notifications): improved notification templates (#4321)
  * feat(general): misc notifications improvements (#4319)
  * build(deps): bump the common-golang-dependencies group with 4
    updates (#4314)
  * build(deps): bump the telemetry-dependencies group with 4
    updates (#4312)
  * feat(ui): upgraded htmlui to the latest version (#4317)
  * feat(kopiaui): support for AppArmor on Ubuntu 24.04 (#4318)
  * build(deps): bump the common-golang-dependencies group with 4
    updates (#4311)
  * feat(ui): upgraded htmlui to the latest version (#4301)
  * feat(ui): upgraded htmlui to the latest version (#4300)
  * build(deps): bump the common-golang-dependencies group across 1
    directory with 3 updates (#4299)
  * build(deps): bump github.com/prometheus/common (#4298)
  * build(deps): bump github/codeql-action in the github-actions
    group (#4286)
  * build(deps): bump github.com/mocktools/go-smtp-mock/v2 (#4277)
  * build(deps): bump codecov/codecov-action from 4.6.0 to 5.0.7
    (#4287)
  * build(deps): bump the kopia-ui-npm-dependencies group (#4288)
  * build(deps): bump github.com/hanwen/go-fuse/v2 from 2.6.4 to
    2.7.2 (#4291)
  * feat(server): only log successful authentication events when
  - -log-server-requests is enabled (#4296)
  * build(deps): bump github.com/minio/minio-go/v7 (#4290)
  * build(deps): bump github.com/stretchr/testify from 1.9.0 to
    1.10.0 (#4275)
  * build(deps): bump google.golang.org/api (#4274)
* Thu Nov 21 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.18.2:
  * feat(general): JSON marshaler helper for `time.Duration`
    (#4194)
  * feat(ui): upgraded htmlui to the latest version (#4268)
  * feat(snapshots): Fix for #2037 Add symlink support for
    .kopiaignore (#4190)
  * build(deps): bump github.com/hanwen/go-fuse/v2 from 2.6.3 to
    2.6.4 (#4265)
  * build(deps): bump github.com/mocktools/go-smtp-mock/v2 (#4264)
  * build(deps): bump the common-golang-dependencies group with 4
    updates (#4263)
  * fix(server): handle unset password hash version in user profile
    (#4259)
  * fix(notifications): fixed headers for email notifications
    (#4258)
* Tue Nov 19 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.18.1:
  * fix(cli): fixed v0.18.0 failures using v0.17.0-generated config
    (#4255)
* Tue Nov 19 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.18.0:
  There are over 240 changes in this release.
  Full list of changes can be found in:
  https://github.com/kopia/kopia/compare/v0.17.0...v0.18.0
  * Notifications
    You can now define notification profiles to be notified
    whenever errors occur.
  - support for defining notification profiles and templates via
    CLI (#4034) by Jarek Kowalski
  - send error notifications and snapshot reports (#4233) by
    Jarek Kowalski
  - improved snapshot reports (#4244) by Jarek Kowalski
  - added API to manipulate notification profiles in the UI - not
    used yet (#4171) by Jarek Kowalski
  * Maintenance
    Maintenance and manifest management improvements should make
    working with larger repositories somewhat easier.
  - run epoch maintenance for quick maintenance (#4185) by Julio
    López
  - allow running quick maintenance with epoch manager (#4198) by
    Julio López
  - do not run auto-maintenance after a command fails (#4168) by
    Julio López
  - Reduce memory usage for epoch index compaction (#4139) by
    lyndon-li
  - Reduce memory allocations during manifest compaction (#4084)
    by ashmrtn
  - remove ability to enable compaction on index load (#3834) by
    Julio López
  - Allow extending blob retentions (#4151) by Mike McKay-Dirden
  * Snapshot/Restore
    Improvements for snapshot/restore progress reporting.
  - introduce adaptive estimation mechanism (#4218) by Eugene
    Sumin
  - Increase restore progress granularity (#3655) by Eugene Sumin
  * Policies
  - add policy import/export commands to im-/export policies
    from/to json ([#4020]) by blenderfreaky
  - added support for per-directory splitter overrides (#3887) by
    Jarek Kowalski
  - Metadata compression config support for directory and
    indirect content (#4080) by Prasad Ghangal
  * Server
  - BREAKING CHANGE remove support for HTTP-based repository API
    (#3745) by Jarek Kowalski
  - add server user set-password-hash command (#3974) by Julio
    López
  - user add set user-password-hashing-algorithm cli option
    (#3815) by Sirish Bathina
  - Fix client IPv6 URI generation for gRPC connections (#3830)
    by Nick
  * Providers
  - GCS immutability (#4134) by Mike McKay-Dirden
  - info about the B2 S3-compatible endpoint (#3860) by Wyatt
    Childers
  - upgraded rclone to 1.68.2, fixed Google Drive rclone
    compatibility (#4249) by Jarek Kowalski
  * Other Notable Changes
  - cache hard limits flags (#3846) by Wyatt Childers
  - avoid memory bloat in benchmark encryption command (#4213) by
    Julio López
  - include clock skew in error message (#4186) by Julio López
  - avoid using empty master keys (#3835) by Mark Severson
  - key derivation algorithm for cache encryption (#3799) by
    Sirish Bathina
  - allow setting key derivation algorithm for format blob
    (#3779) by Sirish Bathina
  - include parameters in pbkdf2 instantiation (#3811) by Julio
    López
  - change default number of iterations for PBKDF2 (#3810) by
    Julio López
* Mon Jul 15 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.17.0:
  * build(deps): bump github.com/klauspost/compress from 1.17.7 to 1.17.8 (#3802)
  * build(deps): bump github/codeql-action in the github-actions group (#3803)
  * build(deps): bump the common-golang-dependencies group with 2 updates (#3801)
  * refactor(repository): refactored internal index read API to reduce memory allocations (#3754)
  * refactor(general): avoid wrapping known-to-be-nil error (#3797)
  * feat(general): User_profile_add_set cli changes (#3770)
  * fix(server): fixed deadlock between server and scheduler during shutdown (#3782)
  * build(deps-dev): bump tar from 6.2.0 to 6.2.1 in /app (#3794)
  * build(deps): bump codecov/codecov-action from 4.1.1 to 4.2.0 (#3792)
  * build(deps): bump docker/setup-buildx-action in the docker group (#3791)
* Mon Jul 15 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- new package kopia: Cross-platform backup tool for Windows, macOS
  & Linux with fast, incremental backups, client-side end-to-end
  encryption, compression and data deduplication
